@@ -12,6 +12,12 @@ class _GenConst(object):
 KEY_UP = _GenConst('↑')
 KEY_DOWN = _GenConst('↓')
 KEY_CTRL_C = _GenConst('Ctrl+C')
+KEY_CTRL_N = _GenConst('Ctrl+N')
+KEY_CTRL_P = _GenConst('Ctrl+P')
+
+KEY_MAPPING = {'\x0e': KEY_CTRL_N,
+               '\x03': KEY_CTRL_C,
+               '\x10': KEY_CTRL_P}
 
 ACTION_SELECT = _GenConst('select')
 ACTION_ABORT = _GenConst('abort')
@@ -71,3 +77,7 @@ CONFIGURATION_TIMEOUT = 60
 USER_COMMAND_MARK = u'\u200B' * 10
 
 LOG_SIZE = 1000
+
+LOG_SIZE_IN_BYTES = 1024 * 1024
+
+DIFF_WITH_ALIAS = 0.5
