@@ -3,7 +3,7 @@ from thefuck.utils import for_app
 
 @for_app('ag')
 def match(command):
-    return command.stderr.endswith('run ag with -Q\n')
+    return command.output.endswith('run ag with -Q\n')
 
 
 def get_new_command(command):
