@@ -7,9 +7,11 @@ from thefuck.shells import shell
 @sudo_support
 @for_app('cd')
 def match(command):
-    return (('no such file or directory' in command.stderr.lower()
-             or 'cd: can\'t cd to' in command.stderr.lower()
-             or 'the system cannot find the path specified.' in command.stderr.lower()))
+    return (
+        'no such file or directory' in command.output.lower()
+        or 'cd: can\'t cd to' in command.output.lower()
+        or 'the system cannot find the path specified.' in command.output.lower()
+    )
 
 
 @sudo_support
