@@ -4,8 +4,8 @@ from thefuck.specific.git import git_support
 @git_support
 def match(command):
     return (' rm ' in command.script and
-            'error: the following file has changes staged in the index' in command.stderr and
-            'use --cached to keep the file, or -f to force removal' in command.stderr)
+            'error: the following file has changes staged in the index' in command.output and
+            'use --cached to keep the file, or -f to force removal' in command.output)
 
 
 @git_support
