@@ -3,7 +3,7 @@ from thefuck.utils import for_app
 
 @for_app('ls')
 def match(command):
-    return command.stdout.strip() == ''
+    return command.output.strip() == ''
 
 
 def get_new_command(command):
