@@ -3,10 +3,10 @@ from thefuck.utils import get_closest, for_app
 
 
 def extract_possibilities(command):
-    possib = re.findall(r'\n\(did you mean one of ([^\?]+)\?\)', command.stderr)
+    possib = re.findall(r'\n\(did you mean one of ([^\?]+)\?\)', command.output)
     if possib:
         return possib[0].split(', ')
-    possib = re.findall(r'\n    ([^$]+)$', command.stderr)
+    possib = re.findall(r'\n    ([^$]+)$', command.output)
     if possib:
         return possib[0].split(' ')
     return possib
@@ -14,10 +14,10 @@ def extract_possibilities(command):
 
 @for_app('hg')
 def match(command):
-    return ('hg: unknown command' in command.stderr
-            and '(did you mean one of ' in command.stderr
-            or "hg: command '" in command.stderr
-            and "' is ambiguous:" in command.stderr)
+    return ('hg: unknown command' in command.output
+            and '(did you mean one of ' in command.output
+            or "hg: command '" in command.output
+            and "' is ambiguous:" in command.output)
 
 
 def get_new_command(command):
